/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.prediction.model;

import com.google.api.client.json.GenericJson;

/**
 * Model definition for Output.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Prediction API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class Output extends GenericJson {

  /**
   * The unique name for the predictive model.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String id;

  /**
   * What kind of resource this is.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * The most likely class label (Categorical models only).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String outputLabel;

  /**
   * A list of class labels with their estimated probabilities (Categorical models only).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<OutputMulti> outputMulti;

  static {
    // hack to force ProGuard to consider OutputMulti used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(OutputMulti.class);
  }

  /**
   * The estimated regression value (Regression models only).
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String outputValue;

  /**
   * A URL to re-request this resource.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String selfLink;

  /**
   * The unique name for the predictive model.
   * The value returned may be {@code null}.
   */
  public String getId() {
    return id;
  }

  /**
   * The unique name for the predictive model.
   * The value set may be {@code null}.
   */
  public Output setId(String id) {
    this.id = id;
    return this;
  }

  /**
   * What kind of resource this is.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * What kind of resource this is.
   * The value set may be {@code null}.
   */
  public Output setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * The most likely class label (Categorical models only).
   * The value returned may be {@code null}.
   */
  public String getOutputLabel() {
    return outputLabel;
  }

  /**
   * The most likely class label (Categorical models only).
   * The value set may be {@code null}.
   */
  public Output setOutputLabel(String outputLabel) {
    this.outputLabel = outputLabel;
    return this;
  }

  /**
   * A list of class labels with their estimated probabilities (Categorical models only).
   * The value returned may be {@code null}.
   */
  public java.util.List<OutputMulti> getOutputMulti() {
    return outputMulti;
  }

  /**
   * A list of class labels with their estimated probabilities (Categorical models only).
   * The value set may be {@code null}.
   */
  public Output setOutputMulti(java.util.List<OutputMulti> outputMulti) {
    this.outputMulti = outputMulti;
    return this;
  }

  /**
   * The estimated regression value (Regression models only).
   * The value returned may be {@code null}.
   */
  public String getOutputValue() {
    return outputValue;
  }

  /**
   * The estimated regression value (Regression models only).
   * The value set may be {@code null}.
   */
  public Output setOutputValue(String outputValue) {
    this.outputValue = outputValue;
    return this;
  }

  /**
   * A URL to re-request this resource.
   * The value returned may be {@code null}.
   */
  public String getSelfLink() {
    return selfLink;
  }

  /**
   * A URL to re-request this resource.
   * The value set may be {@code null}.
   */
  public Output setSelfLink(String selfLink) {
    this.selfLink = selfLink;
    return this;
  }

  /**
   * Model definition for OutputOutputMulti.
   */
  public static final class OutputMulti extends GenericJson {

    /**
     * The class label.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String label;

    /**
     * The probability of the class label.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String score;

    /**
     * The class label.
     * The value returned may be {@code null}.
     */
    public String getLabel() {
      return label;
    }

    /**
     * The class label.
     * The value set may be {@code null}.
     */
    public OutputMulti setLabel(String label) {
      this.label = label;
      return this;
    }

    /**
     * The probability of the class label.
     * The value returned may be {@code null}.
     */
    public String getScore() {
      return score;
    }

    /**
     * The probability of the class label.
     * The value set may be {@code null}.
     */
    public OutputMulti setScore(String score) {
      this.score = score;
      return this;
    }

  }

}
